
use "${DATA_PATH}\SIRENE\sir_sto_et_1987_1992", clear
	append using "${DATA_PATH}\DADS\dads_et_1993_2002_red.dta"
	append using "${DATA_PATH}\CLAP\clap_et_2003_2015_red.dta"
	replace apet = substr(apet,1,2)
	destring apet, replace force
	order siret year 
	sort siret year
	
	replace marchet="0" if marchet=="MA"
	replace marchet="1" if marchet=="PR"
	replace marchet="2" if marchet=="PU"
	drop if marchet=="HC"

	replace marchet="2" if marchet=="0" & year==2006
	replace marchet="0" if marchet=="1" & year==2006
	replace marchet="1" if marchet=="2" & year==2006

	destring marchet, replace
	replace etabmna="1" if (marchet==0 & apet>5 & year<2007 & year>1992)
	replace etabmna="1" if (year<=1992)

	replace etabmna="1" if (marchet==0 & apet>3 & year==2010)

	keep if etabmna=="1"	
	drop etabmna marchet	

	bys siret year: gen t = _N
	drop if t != 1
	drop t
	sort siret year

/* Step 1 */

	sort siret year_et
	by siret: replace year_et = year_et[1]	
	by siret: replace month_et = month_et[1]	
	by siret: replace dep_et = dep_et[1]
	
	drop if effeqtp==0
	drop if effeqtp==.
	sort siret year
	by siret: gen trou = (year[_n-1] != year - 1 ) & (_n != 1)
	by siret: egen m = mean(trou)
	drop if m != 0
	drop m trou	

	by siret: egen year_disp = max(year)
	replace year_disp = . if year_disp == 2015

	keep  siret year year_et month_et dep_et apet cj year_disp effeqtp
	
/* Step 2 */

	tostring cj, replace
	gen cj_red = substr(cj,1,1)
	drop cj
	rename cj_red cj
	tab cj
	drop if cj=="4" | cj=="6" | cj=="7" | cj=="8" | cj=="9"

	drop cj
	xtset siret year
	tsfill, full

	recode effeqtp (missing=0)

	sort siret year_et
	by siret: replace year_et = year_et[1]
	by siret: replace month_et = month_et[1]
	by siret: replace dep_et = dep_et[1]
	gen age = [(12-month_et)+(year-year_et)*12]/12
	drop month_et
	replace age=round(age)
	drop if age<0

	sort siret year_disp
	by siret: replace year_disp = year_disp[1] if year_disp == .

	rename dep_et dep
	merge m:1 dep using "${DATA_PATH}/Other/corres_dep_reg"
	drop _merge
 
	sort siret year
	
save "${DATA_PATH}/Working/working_db", replace

/* Compute MG - Departement Level */

use "${DATA_PATH}/Working/working_db", clear

	gen X = effeqtp * ((age>=$age) & (year_disp >= year+1)) 
	gen Y = effeqtp * (age>=$age)
	gen Z = F.effeqtp * ((age>=$age) & (year_disp >= year+1))
	replace Z = 0 if Z == . 
	gen W =F.effeqtp * ( ((age>=$age) | (age == $age -1 )) & (year_disp >= year+1))
	replace W = 0 if W == .
	drop if year == 2015

	collapse (sum) X Y W Z, by(year dep) fast
	gen MG = log((X/Y)/(Z/W))/($sigma-1)
	display "age="$age, "sigma="$sigma
	replace year = year+1
	preserve
	keep if inrange(year,2004,2015) 
	collapse (mean) MG X Y W Z, by(dep)
save "${RESULTS_PATH}/MG_geo_effeqtp_k${age}_s${sigma}_dep", replace	
	restore
	keep if inrange(year,2004,2014) 
	collapse (mean) MG X Y W Z, by(dep)
save "${RESULTS_PATH}/MG_geo_effeqtp_k${age}_s${sigma}_dep_0414", replace
	
use "${DATA_PATH}/Working/working_db", clear
	keep if inrange(year,2004,2014)
	drop if year>year_disp | year<year_et
	sort siret year
	xtset siret year
		drop if age<0
		keep if inrange(age, 0, 80)
		gen exit=(year==year_disp)
		gen entry=(year==year_et)		
		collapse (sum) entry (sum) exit (count) nb_plant=siret, by(year dep) fast
		gen entry_rate = entry/nb_plant
		gen exit_rate = exit/nb_plant
		gen CD = (entry_rate+exit_rate)/2
		collapse (mean) CD *rate (mean) nb_plant, by(dep)
		replace nb_plant = round(nb_plant)
		drop if dep==""
		drop if nb_plant<1000 | dep==""	| dep=="97"
		merge 1:1 dep using  "${RESULTS_PATH}/MG_geo_effeqtp_k${age}_s${sigma}_dep_0414"
		drop if _merge==2
		drop _merge
save "${RESULTS_PATH}/MG_geo_effeqtp_k${age}_s${sigma}_dep_regression", replace


/* Compute MG - Region Level */

use "${DATA_PATH}/Working/working_db", clear

	gen X = effeqtp * ((age>=$age) & (year_disp >= year+1)) 
	gen Y = effeqtp * (age>=$age)
	gen Z = F.effeqtp * ((age>=$age) & (year_disp >= year+1))
	replace Z = 0 if Z == . 
	gen W =F.effeqtp * ( ((age>=$age) | (age == $age -1 )) & (year_disp >= year+1))
	replace W = 0 if W == .
	drop if year == 2015

	collapse (sum) X Y W Z, by(year reg) fast
	gen MG = log((X/Y)/(Z/W))/($sigma-1)
	display "age="$age, "sigma="$sigma
	replace year = year+1
	keep if inrange(year,2004,2015) 
	collapse (mean) MG X Y W Z, by(reg)
	tabstat MG, by(reg)
save "${RESULTS_PATH}/MG_geo_effeqtp_k${age}_s${sigma}_reg", replace	

