/*  MG_sec.do
	This do files compute MG by sectors */


use "${DATA_PATH}\SIRENE\sir_sto_et_1987_1992", clear
		append using "${DATA_PATH}\DADS\dads_et_1993_2002_red.dta"
		append using "${DATA_PATH}\CLAP\clap_et_2003_2015_red.dta"
	
	/* Continuity in industry classification */
	replace apet=apetbis if inrange(year,2008,2015)	
	
	rename dep_et dep
	rename apet ape
	rename marchet marche
	rename etabmna abmna
	rename year_et year_c
	rename month_et month_c 
	rename siret id
	
/* Step 1 */
	
	replace ape = substr(ape,1,2)
	destring ape, replace force

	order id year 
	sort id year
	
	/* Keep establishments in Non-farm business sector */
	replace marche="0" if marche=="MA"
	replace marche="1" if marche=="PR"
	replace marche="2" if marche=="PU"
	drop if marche=="HC"
	/* Classification problem in 2006 */
	replace marche="2" if marche=="0" & year==2006
	replace marche="0" if marche=="1" & year==2006
	replace marche="1" if marche=="2" & year==2006

	destring marche, replace
	replace abmna="1" if (year<=1992)
	replace abmna="1" if (marche==0 & ape>5 & year<2007 & year>1992)
	
	/* 2010 : variable abmna poorly coded */
	replace abmna="1" if (marche==0 & ape>3 & year==2010)

	keep if abmna=="1"	
	drop abmna marche	

	bys id year: gen t = _N
	drop if t != 1
	drop t
	sort id year
	
save "${DATA_PATH}\Working\working_db", replace
use "${DATA_PATH}\Working\working_db", replace
	drop if ape==.	
	gsort id -year
	by id: gen apet_last_year = ape[1]	
	collapse (count) nb_year=year (mean) apet_last_year, by(id ape)
	bys id : egen nb_year_max = max(nb_year)
	gen apet_max=ape if nb_year==nb_year_max
	drop if apet_max==.	
	drop ape
	duplicates tag id, gen(isdup)
	drop if apet_max != apet_last_year & isdup>0
	rename apet_max ape		
	keep id ape
save "${DATA_PATH}\Working\working_db_sec_apet_id", replace
use "${DATA_PATH}\Working\working_db", replace

	sort id year_c
	by id: replace year_c = year_c[1]	
	by id: replace month_c = month_c[1]
	
	drop ape
	merge m:1 id using "${DATA_PATH}\Working\working_db_sec_apet_id"
	drop _merge
	drop if ${VAR_EMP}==0
	drop if ${VAR_EMP}==.
	sort id year
	by id: gen trou = (year[_n-1] != year - 1 ) & (_n != 1)
	by id: egen m = mean(trou)
	drop if m != 0
	drop m trou	
	/* Generate exit year */
	by id: egen year_disp = max(year)
	replace year_disp = . if year_disp == 2015
	keep  id year year_c month_c ape cj year_disp ${VAR_EMP}
	
erase "${DATA_PATH}\Working\working_db_sec_apet_id.dta"	

/* Step 3 */
	
	/* Delete plants that are subject to specific legal or administrative constraints, 
	such as bailiffs, transportation companies, water supply, university refectory, 
	and mutual funds. */	
	tostring cj, replace
	gen cj_red = substr(cj,1,1)
	drop cj
	rename cj_red cj
	tab cj
	drop if cj=="4" | cj=="6" | cj=="7" | cj=="8" | cj=="9"
	/* Panel creation */	
	drop cj
	xtset id year
	tsfill, full

	recode ${VAR_EMP} (missing=0)

	sort id year_c
	by id: replace year_c = year_c[1]
	by id: replace month_c = month_c[1]
	sort id ape
	by id: replace ape = ape[1] if ape == .
	/* Precise age calculation */
	gen age = [(12-month_c)+(year-year_c)*12]/12
	drop month_c
	replace age=round(age)
	drop if age<0
	/* */
	sort id year_disp
	by id: replace year_disp = year_disp[1] if year_disp == .
	/* */
	sort id year
save "${DATA_PATH}\Working\working_db", replace

/******************************************************************************/
use "${DATA_PATH}\Working\working_db", replace
	/* Sector choice */
	rename ape apet
	merge m:1 apet using "${DATA_PATH}\Other\naf_rev1"
	drop _merge
	sort id year
	/* Generate 4 terms of the missing growth */
	gen X = ${VAR_EMP} * ((age>=$age) & (year_disp >= year+1)) 
	gen Y = ${VAR_EMP} * (age>=$age)
	gen Z = F.${VAR_EMP} * ((age>=$age) & (year_disp >= year+1))
	replace Z = 0 if Z == . 
	gen W =F.${VAR_EMP} * ( ((age>=$age) | (age == $age -1 )))
	replace W = 0 if W == .
	drop if year == 2015
	/* By year */
	replace year = year+1
	collapse (sum) X Y W Z, by(year ${sec}) fast
	gen MG = log((X/Y)/(Z/W))/($sigma-1)
	keep if inrange(year,2004,2012) 
	collapse (mean) MG, by(${sec})
save "${RESULTS_PATH}/MG_sec_${VAR_EMP}_k${age}_s${sigma}_ET", replace	





