/*  build_CLAP.do
	this do file cleans CLAP database from 2003 to 2015 */


use "${DATA_PATH}\DADS\dads_et_2003_export.dta", clear
	gen siret = siren + nic 
	destring siret, replace force
	format siret %17.0g
	drop if siret==.
	keep siret s_brut
save "${DATA_PATH}\DADS\dads_et_2003_export.dta", replace
use "${DATA_PATH}\CLAP\clap_et_2003_export.dta", clear
	merge m:1 siren using "${DATA_PATH}\CLAP\clap_en_red_2003_export.dta"
	drop _merge
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	merge 1:1 siret using "${DATA_PATH}\DADS\dads_et_2003_export.dta"
	drop if _merge==2
	drop _merge
	rename an year
	gen year_et = year(daton)
	gen month_et = month(daton)
	gen dep_et = substr(dc,1,2)
	replace year_et=2003 if year_et==.
	replace month_et=1 if month_et==. 
	rename s_brut rembrute
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet marchet
	order siret year_et
	sort siret
erase "${DATA_PATH}\CLAP\clap_et_2003_export.dta"
save "${DATA_PATH}\CLAP\clap_et_2003_red.dta", replace

use "${DATA_PATH}\CLAP\clap_et_2004_export.dta", clear
	merge m:1 siren using "${DATA_PATH}\CLAP\clap_en_red_2004_export.dta"
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	rename an year
	gen yy = substr(daton,7,2)
	destring yy, replace
	gen year_et = 1900 + yy if (yy>20)
	replace year_et = 2000 + yy if year_et==.
	gen month_et = substr(daton,4,2)
	gen dep_et = substr(dc,1,2)
	destring year_et month_et, replace force
	replace year_et=2004 if year_et==.
	replace month_et=1 if month_et==.
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet marchet
	order siret year_et
	sort siret
erase "${DATA_PATH}\CLAP\clap_et_2004_export.dta"
save "${DATA_PATH}\CLAP\clap_et_2004_red.dta", replace

use "${DATA_PATH}\CLAP\clap_et_2005_export.dta", clear
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	rename an year
	gen year_et = substr(daton,7,4) if daton!=""
	gen month_et = substr(daton,4,2)
	gen dep_et = substr(dc,1,2)
	destring year_et month_et, replace force
	replace year_et=2005 if year_et==.
	replace month_et=1 if month_et==. 
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet marchet
	order siret year_et
	sort siret
erase "${DATA_PATH}\CLAP\clap_et_2005_export.dta"	
save "${DATA_PATH}\CLAP\clap_et_2005_red.dta", replace

use "${DATA_PATH}\CLAP\clap_et_2006_export.dta", clear
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	rename an year
	gen yy = substr(daton,7,2)
	destring yy, replace
	gen year_et = 1900 + yy if (yy>20)
	replace year_et = 2000 + yy if year_et==.
	gen month_et = substr(daton,4,2)
	gen dep_et = substr(dc,1,2)
	destring year_et month_et, replace force
	replace year_et=2006 if year_et==.
	replace month_et=1 if month_et==. 
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet marchet
	order siret year_et
	sort siret
erase "${DATA_PATH}\CLAP\clap_et_2006_export.dta"	
save "${DATA_PATH}\CLAP\clap_et_2006_red.dta", replace
	
/* Remark : In 2007, for sector classification, we keep APET (NAF Rev.1) 
to ensure continuity.*/
use "${DATA_PATH}\CLAP\clap_et_2007_export.dta", clear
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	rename an year
	gen yy = substr(daton,7,2)
	destring yy, replace
	gen year_et = 1900 + yy if (yy>20)
	replace year_et = 2000 + yy if year_et==.
	gen month_et = substr(daton,4,2)
	gen dep_et = substr(dc,1,2)
	destring year_et month_et, replace force
	replace year_et=2007 if year_et==.
	replace month_et=1 if month_et==. 
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet etabmna
	order siret year_et
	sort siret
erase "${DATA_PATH}\CLAP\clap_et_2007_export.dta"
save "${DATA_PATH}\CLAP\clap_et_2007_red.dta", replace

/* Remark : From 2008 to 2013, for sector classification, we keep APETBIS 
(NAF Rev.1) to ensure continuity. */
forvalues j=2008(1)2010{
	use "${DATA_PATH}\CLAP\clap_et_`j'_export.dta", clear
		gen siret = siren + nic 
		destring an cj siret, replace
		format siret %17.0g
		drop if siret==.
		rename an year
		gen yy = substr(daton,8,2)
		destring yy, replace
		gen year_et = 1900 + yy if (yy>20)
		replace year_et = 2000 + yy if year_et==.
		gen month_et = 1 if substr(daton,4,3)=="JAN"
		replace month_et = 2 if substr(daton,4,3)=="FEB"
		replace month_et = 3 if substr(daton,4,3)=="MAR"
		replace month_et = 4 if substr(daton,4,3)=="APR"
		replace month_et = 5 if substr(daton,4,3)=="MAY"
		replace month_et = 6 if substr(daton,4,3)=="JUN"
		replace month_et = 7 if substr(daton,4,3)=="JUL"
		replace month_et = 8 if substr(daton,4,3)=="AUG"
		replace month_et = 9 if substr(daton,4,3)=="SEP"
		replace month_et = 10 if substr(daton,4,3)=="OCT"
		replace month_et = 11 if substr(daton,4,3)=="NOV"
		replace month_et = 12 if substr(daton,4,3)=="DEC"
		gen dep_et = substr(dc,1,2)
		replace year_et=`j' if year_et==.
		replace month_et=1 if month_et==.
		keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet apetbis marchet etabmna
		order siret year_et
		sort siret
	erase "${DATA_PATH}\CLAP\clap_et_`j'_export.dta"	
	save "${DATA_PATH}\CLAP\clap_et_`j'_red.dta", replace
}

forvalues j=2011(1)2013{
	use "${DATA_PATH}\CLAP\clap_et_`j'_export.dta", clear
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	rename an year
	gen yy = substr(daton,7,2)
	destring yy, replace
	gen year_et = 1900 + yy if (yy>20)
	replace year_et = 2000 + yy if year_et==.
	gen month_et = substr(daton,4,2)
	gen dep_et = substr(dc,1,2)
	destring year_et month_et, replace force
	replace year_et=`j' if year_et==.
	replace month_et=1 if month_et==. 
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet apetbis etabmna
	order siret year_et
	sort siret
	erase "${DATA_PATH}\CLAP\clap_et_`j'_export.dta"
	save "${DATA_PATH}\CLAP\clap_et_`j'_red.dta", replace
}

forvalues j=2014(1)2015{
	use "${DATA_PATH}\CLAP\clap_et_`j'_export.dta", clear
	gen siret = siren + nic 
	destring an cj siret, replace
	format siret %17.0g
	drop if siret==.
	rename an year
	gen year_et = substr(daton,7,4) if daton!=""
	gen month_et = substr(daton,4,2)
	gen dep_et = substr(dc,1,2)
	destring year_et month_et, replace force
	replace year_et=`j' if year_et==.
	replace month_et=1 if month_et==.
	keep siret year cj year_et month_et eff3112 effeqtp rembrute dep_et apet etabmna
	order siret year_et
	sort siret
	erase "${DATA_PATH}\CLAP\clap_et_`j'_export.dta"
	save "${DATA_PATH}\CLAP\clap_et_`j'_red.dta", replace
}


use "${DATA_PATH}\CLAP\clap_et_2003_red.dta", clear
	forvalues j=2004(1)2015 {
		append using "${DATA_PATH}\CLAP\clap_et_`j'_red.dta"
		erase "${DATA_PATH}\CLAP\clap_et_`j'_red.dta"
	} 
gen siren = floor(siret/10^5)
format siren %17.0g	
order siret siren
save "${DATA_PATH}\CLAP\clap_et_2003_2015_red.dta", replace

erase "${DATA_PATH}\CLAP\clap_et_2003_red.dta"
erase "${DATA_PATH}\CLAP\clap_en_red_2003_export.dta"
erase "${DATA_PATH}\CLAP\clap_en_red_2004_export.dta"
		

