/*  clean_merge.do
	merge all the dataset and build final file to compute MG */

	

if ("${ET_EN}"=="ET") {
	use "${DATA_PATH}\SIRENE\sir_sto_et_1987_1992", clear
		append using "${DATA_PATH}\DADS\dads_et_1993_2002_red.dta"
		
		if ("${VAR_EMP}" == "eff3112" | "${VAR_EMP}" == "effeqtp" | "${VAR_EMP}" == "rembrute") {
			append using "${DATA_PATH}\CLAP\clap_et_2003_2015_red.dta"
			local last_year = 2015
			/* Conversion Franc -> Euro in 2000 */
			replace rembrute = rembrute/6.55957 if year<=1999
		}
		if ("${VAR_EMP}" == "s_nbh") {
			drop if year == 2002
			append using "${DATA_PATH}\DADS\dads_et_2002_red_nbh.dta"
			append using "${DATA_PATH}\DADS\dads_et_2003_2014_red_nbh.dta"
			local last_year = 2014
		}
		if ("${VAR_EMP}" == "va") {
			append using "${DATA_PATH}\CLAP\clap_et_2003_2015_red_va.dta"
			local last_year = 2015
		}
		
		rename dep_et dep
		rename apet ape
		rename marchet marche
		rename etabmna abmna
		rename year_et year_c
		rename month_et month_c 
		rename siret id
				
}
if ("${ET_EN}"=="EN") {
	use "${DATA_PATH}/DADS/dads_en_1993_2002_red.dta", clear
		append using "${DATA_PATH}/CLAP/clap_en_2003_2015_red.dta"
		local last_year = 2015
		
		rename dep_en dep
		rename apen ape
		rename marchen marche
		rename year_en year_c
		rename month_en month_c
		rename siren id


}

/* Step 1 */

	replace ape = substr(ape,1,2)
	destring ape, replace force
	
	order id year 
	sort id year
	
	/* Keep establishments in Non-farm business sector */
	replace marche="0" if marche=="MA"
	replace marche="1" if marche=="PR"
	replace marche="2" if marche=="PU"
	drop if marche=="HC"
	/* Classification problem in 2006 */
	replace marche="2" if marche=="0" & year==2006
	replace marche="0" if marche=="1" & year==2006
	replace marche="1" if marche=="2" & year==2006

	destring marche, replace
	if ("${ET_EN}"=="ET") {
	replace abmna="1" if (year<=1992)
	replace abmna="1" if (marche==0 & ape>5 & year<2007 & year>1992)
	/* 2010 : variable abmna poorly coded */
	replace abmna="1" if (marche==0 & ape>3 & year==2010)
	}
	if ("${ET_EN}"=="EN") {
	gen abmna="1" if (marche==0 & ape>3 & year>2007)
	replace abmna="1" if (marche==0 & ape>5 & year<=2007)
	}

	keep if abmna=="1"	
	drop abmna marche	

	bys id year: gen t = _N
	drop if t != 1
	drop t
	sort id year

/* Step 2 */	
	
	/* Establishment creation date */
	sort id year_c
	by id: replace year_c = year_c[1]	
	by id: replace month_c = month_c[1]
	/* */
	/* Drop establishments with a 0 or a . in the middle of positive employments
	over 1993-2015 */
	drop if ${VAR_EMP}==0
	drop if ${VAR_EMP}==.
	sort id year
	by id: gen trou = (year[_n-1] != year - 1 ) & (_n != 1)
	by id: egen m = mean(trou)
	drop if m != 0
	drop m trou	
	/* Generate exit year */
	by id: egen year_disp = max(year)
	replace year_disp = . if year_disp == `last_year'
	keep  id year year_c month_c ape cj year_disp ${VAR_EMP}

/* Step 3 */
	
	/* Delete plants that are subject to specific legal or administrative constraints, 
	such as bailiffs, transportation companies, water supply, university refectory, 
	and mutual funds. */	
	tostring cj, replace
	gen cj_red = substr(cj,1,1)
	drop cj
	rename cj_red cj
	tab cj
	drop if cj=="4" | cj=="6" | cj=="7" | cj=="8" | cj=="9"
	/* Panel creation */	
	drop cj
	xtset id year
	tsfill, full

	recode ${VAR_EMP} (missing=0)

	sort id year_c
	by id: replace year_c = year_c[1]
	by id: replace month_c = month_c[1]

	/* Precise age calculation */
	gen age = [(12-month_c)+(year-year_c)*12]/12
	drop month_c
	replace age=round(age)
	drop if age<0
	/* */
	sort id year_disp
	by id: replace year_disp = year_disp[1] if year_disp == .
	/* */
	sort id year
save "${DATA_PATH}\Working\working_db", replace

