/*  Master do file, call all other do files
	Generates all Figures/Tables of the paper
	Aghion, Bergeaud, Boppart, Bunel (2018) JEEA
	Firm Dynamics and Growth Measurement in France
*/


clear all
global ROOT = "your_path"
cd "${ROOT}/dofiles"
set more off, perm
set scheme s1mono, perm
set max_memory 16g, perm
set type double, permanently

global DATA_PATH = "${ROOT}/data"
global FIG_PATH = "${ROOT}/results/Figures"
global RESULTS_PATH = "${ROOT}/results"



run build_SIRENE.do
run build_DADS.do
run build_CLAP.do

run build_panel_hrs.do
run build_panel_va.do

run build_DADS_firm.do
run build_CLAP_firm.do


global ET_EN = "ET" // Firm level = EN, plant level = ET


/* Choice of interest variable among : */
/*  1) Headcount (eff3112) */
/*  2) FTE (effeqtp)*/
/*  3) Payroll (rembrute)*/
/*  4) Hours (s_nbh) */
/*  5) VA (va) */

	global VAR_EMP = "effeqtp"
	run clean_merge.do
	global age = 5 // Corresponds to parameter k in the paper
	global sigma = 4 //CES eslasticity
	run Compute_MG.do
	global age = 3 
	global sigma = 4 
	run Compute_MG.do
	global age = 7 
	global sigma = 4 
	run Compute_MG.do
	global age = 5
	global sigma = 5 
	run Compute_MG.do
	global sigma = 3 
	run Compute_MG.do
	
	
	global VAR_EMP = "eff3112"
	run clean_merge.do
	global age = 5 
	global sigma = 4 
	run Compute_MG.do

	global VAR_EMP = "rembrute"
	run clean_merge.do
	global age = 5 
	global sigma = 4 
	run Compute_MG.do

	global VAR_EMP = "s_nbh"
	run clean_merge.do
	global age = 5 
	global sigma = 4 
	run Compute_MG.do

	global VAR_EMP = "va"
	run clean_merge.do
	global age = 5 
	global sigma = 4 
	run Compute_MG.do

	global VAR_EMP = "effeqtp"
	global sec = "sector"
	run MG_sec.do
	run MG_geo.do
	

	global ET_EN = "EN"
	global VAR_EMP = "effeqtp"	
	run clean_merge.do
	global age = 5 
	global sigma = 4 
	run Compute_MG.do
	global VAR_EMP = "eff3112"	
	run clean_merge.do
	global age = 5 
	global sigma = 4 
	run Compute_MG.do
	
	

	
** Sections 1 to 3	
	
// Requested to draw some Figures
global ET_EN = "ET"
global VAR_EMP = "effeqtp"
run clean_merge.do

	
******************* FIGURES **************************
// Figure 1:
	run ./Figures/draw_figure1.do
// Figure 2:
	run ./Figures/draw_figure2.do
// Figure 3:
	run ./Figures/draw_figure3.do	
// Figure 4:
	run ./Figures/draw_figure4.do	
// Figure 5:
	run ./Figures/draw_figure5.do	
	
	
******************** TABLES **************************

// Table 1: Data are taken from www.longtermproductivity.com (accessed April 2018)
// Table 2: 
	run ./Tables/draw_table2.do
// Table 3:
	run ./Tables/draw_table3.do
// Table 4:
	run ./Tables/draw_table4.do
// Table 5:
	run ./Tables/draw_table5.do	
// Table 6:
	run ./Tables/draw_table6.do	
// Table 7:
	run ./Tables/draw_table7.do	
// Table 8:
	run ./Tables/draw_table8.do	

	
** Section 4
	
// Requested to draw some Figures
global ET_EN = "ET"
global VAR_EMP = "eff3112"
run clean_merge.do

******************* FIGURES **************************
// Figure 6:
	run ./Figures/draw_figure6.do
// Figure 7:
	run ./Figures/draw_figure7.do
// Figure 8:
	run ./Figures/draw_figure8.do	
// Figure 9:
	run ./Figures/draw_figure9.do		

	
** Appendix

******************* FIGURES **************************
// Figure A1:
	run ./Figures/draw_figureA1.do
// Figure A2:
	run ./Figures/draw_figureA2.do
// Figure A3:
	run ./Figures/draw_figureA3.do	
// Figure A4:
	run ./Figures/draw_figureA4.do		
	